--
-- ObjectUpdater
--

-- this little class is placed in the actor list and is responsible for
-- passing events to given instantiated objects, thereby avoiding long repeat loops (i.e. when 
-- waiting for a sound to finish)

-- for this to work properly, all given objects must have a stepFrame handler at the root 
-- ancestor.  All stepFrame handlers should call a stepFrame ancestor handler when they are done -- doing their actions.  This will allow updates for all classes that want an update.


property ancestor
property objectList


on new me, obj
  set ancestor = 0
  set objectList = []
  if objectP (obj) then add (objectList, obj)
  return me
end


on destruct me
  set objectList = 0
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


-- add an object to the list:

on addObject me, obj
  if objectP (obj) then add (objectList, obj)
end


-- remove an object from the list:

on removeObject me, obj
  set num = count (objectList)
  repeat with i = 1 to num
    if getAt (objectList, i) = obj then deleteAt (objectList, i)
  end repeat
end



-- pass the stepFrame event to each object in the list:

on stepFrame me
  repeat with obj in objectList
    if objectP (obj) then stepFrame (obj)
  end repeat
end


on actorType me
  return #ObjectUpdater
end
