--
-- DragDropHide
--

-- this class handles all runtime game management.

-- constants:
property delaySecs  -- the number of seconds we delay before moving on to the next round


property ancestor
property responseFlag

--JCODE
global gUI

on new me
  -- initialize constants:
  set delaySecs = 1
  
  set ancestor = new (script "DragDropSetUp")
  set responseFlag = TRUE
  
  --add (the actorList, new (script "ObjectUpdater", me))
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


on noResponse me
  set responseFlag = FALSE
end


on initializeRound me
  hideDraggables (me)
  initializeRound (ancestor)
  showDraggables (me)
  initPlay (me)
end


on mouseDown me, spr
  if not isDraggable (me, spr) then return 0
  
  -- drag until release:
  set testSprite = dragSprite (me, spr)
  if testSprite = -1 then return 1  -- drag ended in starting position (exactly)
  
  -- on release of the mouse
  -- check to see if the sprite is overlapping the correct container:
  
  set matchSprite = checkMatch (me, spr, testSprite)
  hideUnderSprite (me)
  
  if matchSprite then
    
    -- play the good response sound 
    if responseFlag then playResponseSound(1, 1)
    -- play the proper "ID" sound
    playSprite (gUI, spr, #ID)
    
    -- if so, move the draggable off the screen and animate the 'hit' container:
    hideDraggable (me, spr)
    moveOffScreen (me, spr)
    
    updateStage
    animateSprites (me, [matchSprite])  -- animate the matching sprite
    
    -- move a bar graph if one has been set up:
    moveGraph (me, the name of member the memberNum of sprite matchSprite of castLib the castLibNum of sprite matchSprite)
    
    -- we have a match, now check to see if we are done.
    if not done (me) then 
      initPlay (me)
    end if
    
  else
    showDraggable (me, spr)
    -- play the good response sound 
    playResponseSound(0, 1)
  end if
  
  return 1
end



-- check to see if we are done.  
-- if so, then do an action.

on done me
  clearPictLink (me)
  if checkDone (ancestor) then 
    wait (me, delaySecs)
    go "finish"
    unloadCast (me)
    return 1
  else
    return 0
  end if
end


on initPlay me
  initHandCursor ("hand", getDraggableList (me))
end
