--
-- SinglePoint
--

-- this class handles all runtime game management.

-- constants:
property delaySecs  -- the number of seconds we delay before moving on to the next round


property ancestor
property responseFlag

global gUI

on new me
  -- initialize constants:
  set delaySecs = 1
  
  set ancestor = new (script "SinglePointPusher")
  
  set responseFlag = TRUE
  
  -- add (the actorList, new (script "ObjectUpdater", me))
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


on noResponse me
  set responseFlag = FALSE
end


on initializeRound me
  hideDraggables (me)
  initializeRound (ancestor)
  showDraggables (me)
  pushOffDraggables (me)
  initHandCursor ("hand", getDraggableList (me))
  initPlay (me)
end


on mouseDown me, spr
  if not isDraggable (me, spr) then return 0
  
  -- drag until release:
  set testSprite = dragSprite (me, spr)
  if testSprite = -1 then return 1  -- drag ended in starting position (exactly)
  
  -- on release of the mouse
  -- check to see if the sprite is overlapping the correct container:
  
  set matchSprite = checkMatch (me, spr, testSprite)
  hideUnderSprite (me)
  
  if matchSprite then
    -- if a match, snap the draggable to position and stick it there.
    snapToPosition (me, spr, matchSprite)
    stickDraggable (me, spr)
    hideTarget (me, matchSprite)
    updateStage
    
    -- play the good response sound 
    if responseFlag then playResponseSound(1, 1)
    -- play the proper "ID" sound
    playSprite (gUI, spr, #ID)
    
    animateSprites (me, [matchSprite])  -- animate the matching sprite
    
    -- move a bar graph if one has been set up:
    moveGraph (me, the name of member the memberNum of sprite matchSprite of castLib the castLibNum of sprite matchSprite)
    
    moveOffScreen (me, matchSprite)
    if not done (me) then 
      initPlay (me)
    end if
        
  else
    showDraggable (me, spr)
    -- play the negative response sound 
    playResponseSound(0, 1)
  end if
  
  return 1
end



-- initialize an individual play:

on initPlay me
  set activeSpr = pushOnDraggable (me)
  makePictLink (me, activeSpr)
  -- play the intro sound by sprite...
  playSprite (gUI, activeSpr, #prompt)
  initHandCursor ("hand", getDraggableList (me))
end



-- check to see if we are done.  
-- if so, then do an action.

on done me
  clearPictLink (me)
  if checkDone (me) then 
    wait (me, delaySecs)
    go "finish"
    unloadCast (me)
    return 1
  else
    return 0
  end if
end