--
-- DirectionArrows
--

-- this class handles all runtime game management.
-- don't worry about intersections of sprites except bounding sprites, check by direction relative to starting position.
-- for this to work, draggables must be named "north", "south", "east", and "west"

-- constants:
property delaySecs  -- the number of seconds we delay before moving on to the next round


property ancestor
property responseFlag
property activeSpr
property startPoint

global gUI


on new me
  -- initialize constants:
  set delaySecs = 1
  
  set ancestor = new (script "DirectionSprite")
  
  set responseFlag = TRUE
  set startPoint = point (320,240)
  
  -- add (the actorList, new (script "ObjectUpdater", me))
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


on noResponse me
  set responseFlag = FALSE
end


on initializeRound me
  hideDraggables (me)
  initializeRound (ancestor)
  showDraggables (me)
  pushOffDraggables (me)
  -- initHandCursor ("hand", getDraggableList (me))
  initPlay (me)
end


on mouseDown me, spr
  -- watch hardwired direction arrows:
  if spr < 25 or spr > 28 then return 0
  
  -- set up for movement:
  puppetSprite spr, TRUE
  set the memberNum of sprite spr to the memberNum of sprite spr + 1
  set currName = the name of member the memberNum of sprite activeSpr of castLib the castLibNum of sprite activeSpr
  
  -- do the arrow action before checking for match:
  case spr of
    25: set dir = #up
    26: set dir = #down
    27: set dir = #right
    28: set dir = #left
    otherwise return 0
  end case
  
  
  -- actual movement:
  set testSprite = move (me, activeSpr, dir)
  
  -- clean up after movement:
  set the memberNum of sprite spr to the memberNum of sprite spr - 1
  updateStage
  puppetSprite spr, FALSE
  updateStage
  hideUnderSprite (me)
  
  -- have we matched the expected direction?
  set matchDirection = FALSE
  case spr of
    25: if currName = "north" and the locv of sprite activeSpr < the locv of startPoint then set matchDirection = TRUE
    26: if currName = "south" and the locv of sprite activeSpr > the locv of startPoint then set matchDirection = TRUE
    27: if currName = "east"  and the loch of sprite activeSpr > the loch of startPoint then set matchDirection = TRUE
    28: if currName = "west"  and the loch of sprite activeSpr < the loch of startPoint then set matchDirection = TRUE
    otherwise return 0
  end case
  
  if matchDirection then 
    -- play the good response sound
    if responseFlag then playResponseSound(1, 1)
    -- play the proper "ID" sound
    playSprite (gUI, activeSpr, #ID)
    -- if so, move the draggable off the screen and animate the 'hit' container:
    hideDraggable (me, activeSpr)
    
    updateStage
    if not done (me) then 
      initPlay (me)
    end if
    
  else
    
    if responseFlag then playResponseSound(0, 1)
    set the loc of sprite activeSpr to startPoint
  end if
  
  return 1
end


-- initialize an individual play:

on initPlay me
  set activeSpr = pushOnDraggable (me)
  set startPoint = the loc of sprite activeSpr
  updateStage
  makePictLink (me, activeSpr)
  -- play the intro sound by sprite...
  playSprite (gUI, activeSpr, #prompt)
  -- initHandCursor ("hand", getDraggableList (me))
end



-- check to see if we are done.  
-- if so, then do an action.

on done me
  clearPictLink (me)
  if checkDone (me) then 
    wait (me, delaySecs)
    go "finish"
    return 1
  else
    return 0
  end if
end