--
-- DragDropStick
--

-- this class handles all runtime game management.

-- constants:
property delaySecs  -- the number of seconds we delay before moving on to the next round


property ancestor
property responseFlag  -- do not respond with pos or neg sound on each play
property waitResponseFlag  -- wait on the positive response until completion of the exercise

--JCODE
global gUI

on new me
  -- initialize constants:
  set delaySecs = 1
  
  set ancestor = new (script "DragDropSetUp")
  set responseFlag = TRUE
  set waitResponseFlag = FALSE
  
  --add (the actorList, new (script "ObjectUpdater", me))
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


on noResponse me
  set responseFlag = FALSE
end


on waitResponse me
  set responseFlag = FALSE
  set waitResponseFlag = TRUE
end


on initializeRound me
  hideDraggables (me)
  initializeRound (ancestor)
  showDraggables (me)
  showTargets (me)
  initPlay (me)
end


on mouseDown me, spr
  if not isDraggable (me, spr) then return 0
  
  -- drag until release:
  set testSpr = dragSprite (me, spr)
  if testSpr = -1 then return 1  -- drag ended in starting position (exactly)
  
  -- on release of the mouse
  -- check to see if the sprite is overlapping the correct container:
  
  set matchSprite = checkMatch (me, spr, testSpr)
  hideUnderSprite (me)
  
  if matchSprite then
    -- if a match, snap the draggable to position and stick it there.
    set the castLibNum of sprite spr to the number of castLib "draggablesSwitch"
    snapToPosition (me, spr, matchSprite)
    stickDraggable (me, spr)
    --hideTarget (me, matchSprite)  
    updateStage
    
    -- play the good response sound 
    if responseFlag then playResponseSound(1, 1)
    -- play the proper "ID" sound
    playSprite (gUI, spr, #ID)
    
    -- move a bar graph if one has been set up:
    moveGraph (me, the name of member the memberNum of sprite matchSprite of castLib the castLibNum of sprite matchSprite)
    
    -- moveOffScreen (me, matchSprite)
    
    set lab = string (getID (me, spr))
    
    
    -- if there is an animation label then play that label:
    if the labelList contains lab then
      clearPictLink (me)
      go lab
      
      -- otherwise check to see if we are done with the activity:
    else
      
      if not done (me) then 
        initPlay (me)
      end if
      
    end if
    
  else
    -- if no match, then move it back to it's starting position:
    showDraggable (me, spr)
    if responseFlag then playResponseSound(0, 1)
  end if
  
  return 1  
end



-- check to see if we are done.  
-- if so, then do an action.

on done me
  if checkDone (ancestor) then 
    if waitResponseFlag then playResponseSound (1,1)
    updateStage
    wait (me, delaySecs)
    go "finish"
    unloadCast (me)
    return 1
  else
    return 0
  end if
end


on initPlay me
  initHandCursor ("hand", getDraggableList (me))
end
