--
-- MatchListMgmt
--

property ancestor

property spriteList  -- the appList contains general information needed to run the application.
property memberList  -- property list of castLibs containing a list of available member nums.

-- the following are all constants:
property appDataMember  -- the member (name) that contains the appList


on new me
  -- set constants:
  set appDataMember = "ActivityPredefines"  -- currently we are using the name of the storage field.
  
  
  set ancestor = new (script "ActivityLib")
  
  -- if we are a projector or protected movie then simply get the data from the appDataMember,
  -- otherwise initialize empty lists.
  divideLists (me, 0)
  
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


-- divide up the master list into easily accessable parts
-- the master list must be formatted correctly.

on divideLists me, lst
  if lst = 0 then
    set spriteList = [:]
    set memberList = [:]
  else
    set spriteList = getProp (lst, #sprites)
    set memberList = getProp (lst, #members)
  end if
end


-- set the starting appList manually:

on setList me, lst
  makeField (me, appDataMember, lst)
  divideLists (me, lst)
end



-- runtime initialization of the game  spriteList:
-- by this point spriteList will have been initialized.
-- each item in the prop list will be as follows:

-- spriteNum:[#coverNum:the memberNum of sprite spr, #coverLib: the castLibNum of sprite spr, #loc:(the loc of sprite spr), #identifier:#empty, #myNum:0, #myLib:answerCast1, #matchSprite:0, #matchSprite2:0, #showflag:0 ]

on initializeRound me
  divideLists (me, value (field appDataMember))
  set mem1 = getPropAt (memberList, 1)
  set memLst1 = getProp (memberList, mem1)  -- this is returning a pointer!!!!
  set mem2 = getPropAt (memberList, 2)
  set memLst2 = getProp (memberList, mem2)
  --  set mem3 = getPropAt (memberList, 3)
  --  set memLst3 = getProp (memberList, mem3)
  
  set listPool = spriteList
  set spriteList = [:]
  repeat while count (listPool)
    
    -- get a random record from the listPool:
    set poolRecNum = random (count (listPool))
    -- hold that record's information:
    set spr = getPropAt (listPool, poolRecNum)
    set lst = getProp (listPool, spr)
    -- delete that record from the listPool:
    deleteProp (listPool, spr)    
    
    -- get another random record from the listPool:
    set poolRecNum2 = random (count (listPool))
    -- hold that record's information:
    set spr2 = getPropAt (listPool, poolRecNum2)
    set lst2 = getProp (listPool, spr2)
    -- delete that record from the listPool:
    deleteProp (listPool, spr2)
    
    
    -- initialize properties - using only members that have identical names:
    
    -- get a random member for the first list:
    set num = random (count (memLst1))
    -- store that member's name identifier and number in the spriteList:
    set id = getPropAt (memLst1, num)
    setAProp (lst, #identifier, id)
    setAProp (lst, #myNum, getProp (memLst1, id))
    setAProp (lst, #myLib, mem1)
    
    -- set props for the second sprite record:
    setAProp (lst2, #identifier, id)
    setAProp (lst2, #myNum, getProp (memLst2, id))
    setAProp (lst2, #myLib, mem2)
    
    -- assign the matching sprites:
    setAProp (lst, #matchSprite, spr2)
    setAProp (lst2, #matchSprite, spr)
    
    -- delete the used member from the initializing memLst
    deleteProp (memLst1, id)
    
    -- put our sprite records back into the master list:
    setaProp (spriteList, spr, lst)
    setaProp (spriteList, spr2, lst2)
  end repeat
end



-- puppet all used sprites to TRUE
-- assign each sprite its personal cover member

on hideAnswerCards me
  repeat with i = 1 to count (spriteList)
    set spr = getPropAt (spriteList, i)
    hideAnswerCard (me, spr)
  end repeat
  unloadCast (me)
  
  repeat with lst in spritelist
    preLoadMember member getProp (lst, #myNum) of castLib getProp (lst, #myLib)
  end repeat
end


-- hide an answer card by sprite number:

on hideAnswerCard me, spr
  set lst = getProp (spriteList, spr)
  
  set spr = integer(spr)
  puppetSprite spr, TRUE
  set the memberNum of sprite spr to getProp (lst, #coverNum)
  set the castLibNum of sprite spr to getProp (lst, #coverLib)
  set the loc of sprite spr to getProp (lst, #loc)
  -- unloadCast (me)
  setAProp (lst, #showFlag, 0)
  setAProp (spriteList, spr, lst)
end


-- show an answerCard by sprite number.
-- return TRUE if a successful card turning.

on showAnswerCard me, spr
  set lst = getAProp (spriteList, spr)
  if voidP (lst) then return 0
  if getProp (lst, #showFlag) then return 0
  
  set the memberNum of sprite spr to getProp (lst, #myNum)
  set the castLibNum of sprite spr to getProp (lst, #myLib)
  
  -- unloadCast (me)
  setAProp (lst, #showFlag, 1)
  setAProp (spriteList, spr, lst)
  return 1
end


-- check for a match by sprite number.
-- return zero or the matching sprite number.

on checkMatch me, spr
  repeat with i = 1 to count (spriteList)
    set spr2 = getPropAt (spriteList, i)
    set lst = getProp (spriteList, spr2)
    
    if spr = getAProp (lst, #matchSprite) then
      if getAProp (lst, #showFlag) then
        return spr2
      end if
    end if
  end repeat
  
  return 0
end


on checkDone me
  repeat with i = 1 to count (spriteList)
    set spr = getPropAt (spriteList, i)
    set lst = getProp (spriteList, spr)
    if not getAProp (lst, #showFlag) then
      return 0
    end if
  end repeat
  return 1
end


on getMatchPieceList me
  set lst = []
  set tot = count (spriteList)
  repeat with i = 1 to tot
    add (lst, getPropAt (spriteList, i))
  end repeat
  return lst
end
