--
-- MatchSetUp
--

-- this class handles the pre-runtime initialization of Match Game data.
-- this class can be discarded before protecting movies for distribution.

property ancestor

-- the following are constants:
property spriteColor  -- the scoreColor of sprites that will be used for the Match Game
property answerCast1, answerCast2, answerCast3  -- the casts of the answerKeys


on new me
  -- set up all constants first:
  set spriteColor = 2  -- corresponds to green in the score. (0 = white)
  set answerCast1 = the number of castLib "Match1"
  set answerCast2 = the number of castLib "Match2"
  
  set ancestor = new (script "MatchGroupListMgmt")
  setUp (me) -- automatic setup for authoring.
  
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


-- do all pre-runtime setup work for the class and return to starting frame:
-- (frame motion disabled for Nystrom set)
-- do NOT make this call from within other runtime code!

on setUp me
  -- set startFrame = the frame
  -- go frame setUpFrame
  
  -- initialize usable lists and check their integrity:
  set spriteInfo = gatherSpriteInfo (me)
  if not listP (spriteInfo) then
    alert "Problem gathering sprite info."
    return 0
  end if
  
  set memberInfo = gatherMemberInfo (me)
  if not listP (memberInfo) then
    alert "Problem gathering member info."
    return 0
  end if
  
  -- add all correctly created lists to the project:
  set initList = [:]
  addProp (initList, #sprites, spriteInfo)
  addProp (initList, #members, memberInfo)
  setList (me, initList)
  
  -- go frame startFrame
  
  -- if we have gotten to this point then do an ancestor setUp:
  return setUp (ancestor)
end



-- gather information of sprites to be used in the Match Game:

on gatherSpriteInfo me
  global gTotalSprites
  set initList = [:]
  set num = 0
  
  --cycle through all sprites:
  repeat with spr = 1 to gTotalSprites
    
    -- sprites must be a certain color to be used in the Match Game:
    if the scoreColor of sprite spr = spriteColor then
      set num = num + 1
      -- gather usable information:
      set tmpLst = [#coverNum:the memberNum of sprite spr, #coverLib: the castLibNum of sprite spr, #loc:(the loc of sprite spr), #identifier:#empty, #myNum:0, #myLib:0, #matchSprite:0, #matchSprite2:0, #showFlag:0]
      
      -- add to the initList
      addProp (initList, spr, tmpLst)
    end if
  end repeat
  
  
  if (num/2)*2 <> num then 
    alert "There are an uneven number of match sprites:"&&num
    return 0
  end if
  
  if not count (initList) then alert "There are no match sprites for this activity.  Check sprite score colors."
  
  return initList
end



-- gather information on members and castLibs to be used in the match game:

on gatherMemberInfo me
  set m1 = getAvailableMemberList (me, answerCast1)
  set m2 = getAvailableMemberList (me, answerCast2)
  -- set m3 = getAvailableMemberList (me, answerCast3)
  
  -- check that m1 has corresponding members in m2:
  -- (currently there is no support for m3)
  if not checkPropMatches (me, m1, m2) then 
    put "Not all of the member names of castlib" && answerCast1 && "have matching members in castlib" && answerCast2 && "(See the message window for specifics)"
    return 0
  end if
  
  -- add possible animations for these members:
  addAnimations (me, answerCast1, m1)
  addAnimations (me, answerCast2, m2)
  -- addAnimations (me, answerCast3, m3)
  
  -- gather the lists of potential members:
  set memList = [:]
  addProp (memList, answerCast1, m1)
  addProp (memList, answerCast2, m2)
  -- addProp (memList, answerCast3, m3)
  
  return memList
end