--
-- ClickSetUp
--

-- this class handles the pre-runtime initialization of Match Game data.
-- this class can be discarded before protecting movies for distribution.

property ancestor

-- the following are constants:
property spriteColor  -- the scoreColor of sprites that will be used for the Match Game
property answerCast1  -- the castLib of the answerKeys


on new me
  -- set up all constants first:
  set spriteColor = 2  -- corresponds to green in the score. (0 = white)
  set answerCast1 = the number of castLib "clickables"
  
  set ancestor = new (script "ClickListMgmt")
  setUp (me) -- automatic setup
  
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


-- do all pre-runtime setup work for the class and return to starting frame:
-- (frame motion disabled for Nystrom set)

on setUp me
  -- set startFrame = the frame
  -- go frame setUpFrame
  
  -- initialize usable lists and check their integrity:
  set spriteInfo = gatherSpriteInfo (me)
  if not listP (spriteInfo) then
    alert "Problem gathering sprite info."
    return 0
  end if
  
  set memberInfo = gatherMemberInfo (me)
  if not listP (memberInfo) then
    alert "Problem gathering member info."
    return 0
  end if
  
  -- add all correctly created lists to the project:
  set initList = [:]
  addProp (initList, #sprites, spriteInfo)
  addProp (initList, #members, memberInfo)
  setList (ancestor, initList)
  
  -- go frame startFrame
  
  -- if we have gotten to this point then do an ancestor setUp:
  return setUp (ancestor)
end



-- gather information of sprites to be used in the Match Game:

on gatherSpriteInfo me
  set initList = [:]
  set num = 0
  
  --cycle through all sprites:
  repeat with spr = 1 to numSprites (me)
    
    -- sprites must be a certain color to be used in the Match Game:
    if the scoreColor of sprite spr = spriteColor then
      set num = num + 1
      -- gather usable information:
      set tmpLst = [#coverNum:0, #coverLib: 0, #loc:(the loc of sprite spr), #identifier:value ("#" & the name of member the memberNum of sprite spr of castLib the castLibNum of sprite spr), #myNum:the memberNum of sprite spr, #myLib:the castLibNum of sprite spr, #matchSprite:0, #matchSprite2:0, #showFlag:0]
      
      -- add to the initList
      addProp (initList, spr, tmpLst)
    end if
  end repeat
  
  if not count (initList) then alert "There are no clickable sprites for this activity.  Check sprite score colors."
  return initList
end



-- gather information on members and castLibs to be used in the match game:

on gatherMemberInfo me
  set m1 = getAvailableMemberList (me, answerCast1)
  
  -- add possible animations for these members:
  addAnimations (me, answerCast1, m1)
  
  -- gather the lists of potential members:
  set memList = [:]
  addProp (memList, answerCast1, m1)
  
  return memList
end