--
-- ClickListMgmt
--
-- the basic click and identify game
-- 'hidden' in this context refers to sprites that haven't been clicked yet.

property ancestor

property spriteList  -- the appList contains general information needed to run the application.
property membereList  -- property list of castLibs containing a list of available member nums.

-- the following are all constants:
property appDataMember  -- the member (name) that contains the appList

property currentID  -- the identifier currently being played.
property removeFlag  -- if TRUE then move the clicked item off the screen.

property randomFlag
property poolOrderFlag


on new me
  -- set constants:
  set appDataMember = "ActivityPredefines"  -- currently we are using the name of the storage field.
  
  set ancestor = new (script "ActivityLib")
  
  divideLists (me, 0)
  set tempList = [:]
  set currentSpriteList = [:]
  set removeFlag = FALSE
  set randomFlag = TRUE
  set poolOrderFlag = FALSE
  
  return me
end


on destruct me
  if objectP (ancestor) then destruct (ancestor)
  set ancestor = 0
end


on randomOff me
  set randomFlag = FALSE
end


on setByPoolOrder me
  set randomFlag = FALSE
  set poolOrderFlag = TRUE
end


-- divide up the master list into easily accessable parts
-- the master list must be formatted correctly.

on divideLists me, lst
  if lst = 0 then
    set spriteList = [:]
    set memberList = [:]
  else
    set spriteList = getProp (lst, #sprites)
    set memberList = getProp (lst, #members)
  end if
end


-- remove clicked graphics from the screen after hit:

on removeClicked me
  set removeFlag = TRUE
end


-- set the starting appList manually:

on setList me, lst
  makeField (me, appDataMember, lst)
  divideLists (me, lst)
end


-- don't give the option of getting the list.
-- all manipulation will happen here.

on getList me
  alert "The appList is to remain inaccessable."
end


-- runtime initialization of the game  spriteList:
-- by this point spriteList will have been initialized.
-- each item in the prop list will be as follows:

-- spriteNum:[#coverNum:0, #coverLib: 0, #loc:(the loc of sprite spr), #identifier:value ("#" & the name of member the memberNum of sprite spr...), #myNum:the memberNum of sprite spr, #myLib:the castLibNum of sprite spr, #matchSprite:0, #matchSprite2:0, #showflag:0 ]


on initializeRound me
  divideLists (me, value (field appDataMember))
end


-- puppet all used sprites to TRUE
-- assign each sprite its personal cover member

on hideAnswerCards me
  set num = count (spriteList)
  repeat with i = 1 to num
    set spr = integer (getPropAt (spriteList, i))
    set lst = getAt (spriteList, i)
    setAProp (lst, #showFlag, 0)  -- hide the answer card
    setAProp (spriteList, spr, lst)
  end repeat
end


on showAnswerCards me
  set num = count (spriteList)
  repeat with i = 1 to num
    set spr = integer (getPropAt (spriteList, i))
    set lst = getAt (spriteList, i)
    setAProp (lst, #showFlag, 1)  -- show the answer card regardless of current state
    --    puppetSprite spr, TRUE
    --    set the memberNum of sprite spr to getProp (lst, #myNum)
    --    set the castLibNum of sprite spr to getProp (lst, #myLib)
    setAProp (spriteList, spr, lst)
  end repeat
end



-- hide an answer card by sprite id of the passed sprite number.
-- repeat until all similar sprites of id are hidden.
-- reconstruct the list to do this.

on hideAnswerCard me, spr
  set id = getID (me, spr)
  
  set num = count (spriteList)
  repeat with i = 1 to num
    set spr = integer (getPropAt (spriteList, i))
    set lst = getAt (spriteList, i)
    if id = getAProp (lst, #identifier) then 
      setAProp (lst, #showFlag, 0)  -- hide the answer card regardless of current state
    end if
    setAProp (spriteList, spr, lst)
  end repeat
  
  unloadCast (me)
end



-- show an answerCard by sprite number.
-- return TRUE if a successful card turning.

on showAnswerCard me, spr, command
  set id = getID (me, spr)
  set num = count (spriteList)
  
  if command = #single then   -- only kill the current sprite hotspot.  Not related hotspots.
    set lst = getAProp (spriteList, spr)
    setAProp (lst, #showFlag, 1)  -- hide the answer card
    setAProp (spriteList, spr, lst)
  else
    repeat with i = 1 to num
      set spr = integer (getPropAt (spriteList, i))
      set lst = getAt (spriteList, i)
      if id = getAProp (lst, #identifier) then
        setAProp (lst, #showFlag, 1)  -- hide the answer card
        if removeFlag then moveOffScreen (me, spr)
        --      puppetSprite spr, TRUE
        --      set the memberNum of sprite spr to getProp (lst, #myNum)
        --      set the castLibNum of sprite spr to getProp (lst, #myLib)
      end if
      setAProp (spriteList, spr, lst)
    end repeat
  end if
  
  unloadCast (me)
  
  return 1
end


-- check to see if a sprite is a clickable sprite:
-- currently does not care if hidden or showing.
-- another possibility is to check our sprite against the clickableList 
-- rather than the spriteList.

on isClickable me, spr
  set num = count (spriteList)
  repeat with i = 1 to num
    if spr = getPropAt (spriteList, i) then return 1
  end repeat
  return 0
end



-- return a list of the clickable sprites:

on getClickableList me
  set rLst = []
  set num = count (spriteList)
  repeat with i = 1 to num
    set spr = getPropAt (spriteList, i)
    set lst = getAProp (spriteList, spr)
    set show = getAProp (lst, #showFlag)
    if not show then add (rLst, spr)
  end repeat
  return rLst
end



-- check for a match with the currently being played identifier and the identifier related to the passed sprite.

on checkMatch me, spr
  if currentID = getID (me, spr) then return 1
  else return 0
end


on checkDone me
  repeat with i = 1 to count (spriteList)
    set spr = getPropAt (spriteList, i)
    set lst = getProp (spriteList, spr)
    if isHidden (me, spr) then return 0
  end repeat
  return 1
end


-- initialize a round of play by choosing a sprite from the spriteList:

on initPlay me
  -- first get the playable list of identifiers.  There can be no repeat identifiers in the pool or that would
  -- upset the even distribution:
  set playList = [:]
  set num = count (spriteList)
  repeat with i = 1 to num
    set spr = getPropAt (spriteList, i)
    if isHidden (me, spr) then
      set id = getID (me, spr)
      setAProp (playList, id, spr)  -- no duplicates will be added and we have easy access to the id.
    end if
  end repeat
  
  
  if randomFlag then
    -- then randomly choose an id:
    set num = random (count (playList))
  else 
    set num = 1
  end if
  
  if not num then put "There are no more clickable sprites.  The game should be over."
  
  set currentID = getPropAt (playList, num)
  set spr = getAProp (playList, currentID)
  return spr  -- return a sprite number to comply with other games.
end


-- lst = type sprite list.

on getID me, spr
  set lst = getAProp (spriteList, spr)
  return getAProp (lst, #identifier)
end


on isHidden me, spr
  set lst = getAProp (spriteList, spr)
  return not getAProp (lst, #showFlag)
end